# overskudd_max()
from .overskudd_max_fil import (
    tmp)
from .overskudd_maks_fil import (
    tmp)

# reggis()
from .reggis_fil import (
    reggis)
from .reggis_cas_fil import (
    reggis_cas)

# superlos()
from .superlos_fil import (
    superløs)
from .superlos_fil import (
    Eq,
    Reals,
    core,
    Symbol,
    ConditionSet,
    FiniteSet,
    Intersection,
    solve,
    solveset,
    nsolve)

